@@ -73,6 +73,8 @@ is" without express or implied warranty.
 
 #include "Xatom.h"
 
+#include <errno.h>
+
 static int nxagentXkbGetNames(char **rules, char **model, char **layout,
                                   char **variant, char **options);
 
@@ -1816,11 +1818,17 @@ void nxagentKeycodeConversionSetup(void)
         if ( doptions != NULL )
           fprintf(keyboard_file, "options=%s\n", doptions);
         fclose(keyboard_file);
+        fprintf(stderr, "keyboard file created\n");
+      }
+      else {
+        int save_err = errno;
+        fprintf(stderr, "keyboard file not created: %s\n", strerror(save_err));
       }
       free(keyboard_file_path);
-      fprintf(stderr, "keyboard file created\n");
     }
-    fprintf(stderr, "SessionPath not defined\n");
+    else {
+      fprintf(stderr, "SessionPath not defined\n");
+    }
   }
   else
   {
